@@ -30,6 +30,9 @@ board %>% pin_read("mtcars")
 ## -----------------------------------------------------------------------------
 board %>% pin_meta("mtcars")
 
+## ---- echo=FALSE--------------------------------------------------------------
+Sys.sleep(1)
+
 ## -----------------------------------------------------------------------------
 board %>% pin_write(mtcars, 
   description = "Data extracted from the 1974 Motor Trend US magazine, and comprises fuel consumption and 10 aspects of automobile design and performance for 32 automobiles (1973–74 models).",
